@@ -11,6 +11,7 @@ from cognite.client._api_client import APIClient
 from cognite.client.data_classes import Datapoints, DatapointsList, DatapointsQuery
 from cognite.client.data_classes.datapoints import DatapointsExternalIdMaybeAggregate, DatapointsIdMaybeAggregate
 from cognite.client.exceptions import CogniteAPIError
+from cognite.client.utils._identifier import Identifier, IdentifierSequence
 
 if TYPE_CHECKING:
     import pandas
@@ -157,8 +158,8 @@ class DatapointsAPI(APIClient):
                 >>> latest_def = res[1][0]
         """
         before = cognite.client.utils._time.timestamp_to_ms(before) if before else None
-        all_ids = cast(List[Dict[str, Union[str, int]]], self._process_ids(id, external_id, wrap_ids=True))
-        is_single_id = self._is_single_identifier(id, external_id)
+        id_seq = IdentifierSequence.load(id, external_id)
+        all_ids = id_seq.as_dicts()
         if before:
             for id_ in all_ids:
                 id_.update({"before": before})
@@ -176,7 +177,7 @@ class DatapointsAPI(APIClient):
         if tasks_summary.exceptions:
             raise tasks_summary.exceptions[0]
         res = tasks_summary.joined_results(lambda res: res.json()["items"])
-        if is_single_id:
+        if id_seq.is_singleton():
             return Datapoints._load(res[0], cognite_client=self._cognite_client)
         return DatapointsList._load(res, cognite_client=self._cognite_client)
 
@@ -272,8 +273,7 @@ class DatapointsAPI(APIClient):
                 >>> data = c.datapoints.retrieve(external_id="abc",start=datetime(2018,1,1),end=datetime(2018,2,2))
                 >>> c.datapoints.insert(data, external_id="def")
         """
-        utils._auxiliary.assert_exactly_one_of_id_or_external_id(id, external_id)
-        post_dps_object = cast(Dict[str, Any], self._process_ids(id, external_id, wrap_ids=True)[0])
+        post_dps_object = Identifier.of_either(id, external_id).as_dict()
         if isinstance(datapoints, Datapoints):
             datapoints = [(t, v) for t, v in zip(datapoints.timestamp, datapoints.value)]
         post_dps_object.update({"datapoints": datapoints})
@@ -346,12 +346,11 @@ class DatapointsAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> c.datapoints.delete_range(start="1w-ago", end="now", id=1)
         """
-        utils._auxiliary.assert_exactly_one_of_id_or_external_id(id, external_id)
         start = utils._time.timestamp_to_ms(start)
         end = utils._time.timestamp_to_ms(end)
         assert end > start, "end must be larger than start"
 
-        delete_dps_object = cast(Dict[str, Any], self._process_ids(id, external_id, wrap_ids=True)[0])
+        delete_dps_object = Identifier.of_either(id, external_id).as_dict()
         delete_dps_object.update({"inclusiveBegin": start, "exclusiveEnd": end})
         self._delete_datapoints_ranges([delete_dps_object])
 
@@ -383,8 +382,7 @@ class DatapointsAPI(APIClient):
                     )
             id = range.get("id")
             external_id = range.get("externalId")
-            utils._auxiliary.assert_exactly_one_of_id_or_external_id(id, external_id)
-            valid_range = cast(Dict[str, Any], self._process_ids(id, external_id, wrap_ids=True)[0])
+            valid_range = Identifier.of_either(id, external_id).as_dict()
             start = utils._time.timestamp_to_ms(range["start"])
             end = utils._time.timestamp_to_ms(range["end"])
             valid_range.update({"inclusiveBegin": start, "exclusiveEnd": end})
