@@ -5,6 +5,7 @@ from cognite.client import utils
 from cognite.client._api_client import APIClient
 from cognite.client.data_classes import Relationship, RelationshipFilter, RelationshipList, RelationshipUpdate
 from cognite.client.data_classes.labels import LabelFilter
+from cognite.client.utils._identifier import IdentifierSequence
 
 
 class RelationshipsAPI(APIClient):
@@ -91,9 +92,7 @@ class RelationshipsAPI(APIClient):
         """
         data_set_ids_processed = None
         if data_set_ids or data_set_external_ids:
-            data_set_ids_processed = cast(
-                List[Dict[str, Any]], self._process_ids(data_set_ids, data_set_external_ids, wrap_ids=True)
-            )
+            data_set_ids_processed = IdentifierSequence.load(data_set_ids, data_set_external_ids).as_dicts()
 
         filter = self._create_filter(
             source_external_ids=source_external_ids,
@@ -159,15 +158,12 @@ class RelationshipsAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> res = c.relationships.retrieve(external_id="1")
         """
-        return cast(
-            Optional[Relationship],
-            self._retrieve_multiple(
-                list_cls=RelationshipList,
-                resource_cls=Relationship,
-                external_ids=external_id,
-                wrap_ids=True,
-                other_params={"fetchResources": fetch_resources},
-            ),
+        identifiers = IdentifierSequence.load(ids=None, external_ids=external_id).as_singleton()
+        return self._retrieve_multiple(
+            list_cls=RelationshipList,
+            resource_cls=Relationship,
+            identifiers=identifiers,
+            other_params={"fetchResources": fetch_resources},
         )
 
     def retrieve_multiple(self, external_ids: List[str], fetch_resources: bool = False) -> RelationshipList:
@@ -189,16 +185,12 @@ class RelationshipsAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> res = c.relationships.retrieve_multiple(external_ids=["abc", "def"])
         """
-        utils._auxiliary.assert_type(external_ids, "external_id", [List], allow_none=False)
-        return cast(
-            RelationshipList,
-            self._retrieve_multiple(
-                list_cls=RelationshipList,
-                resource_cls=Relationship,
-                external_ids=external_ids,
-                wrap_ids=True,
-                other_params={"fetchResources": fetch_resources},
-            ),
+        identifiers = IdentifierSequence.load(ids=None, external_ids=external_ids)
+        return self._retrieve_multiple(
+            list_cls=RelationshipList,
+            resource_cls=Relationship,
+            identifiers=identifiers,
+            other_params={"fetchResources": fetch_resources},
         )
 
     def list(
@@ -260,12 +252,9 @@ class RelationshipsAPI(APIClient):
                 >>> for relationship in c.relationships:
                 ...     relationship # do something with the relationship
         """
-
         data_set_ids_processed = None
         if data_set_ids or data_set_external_ids:
-            data_set_ids_processed = cast(
-                List[Dict[str, Any]], self._process_ids(data_set_ids, data_set_external_ids, wrap_ids=True)
-            )
+            data_set_ids_processed = IdentifierSequence.load(data_set_ids, data_set_external_ids).as_dicts()
 
         filter = self._create_filter(
             source_external_ids=source_external_ids,
@@ -428,5 +417,7 @@ class RelationshipsAPI(APIClient):
                 >>> c.relationships.delete(external_id=["a","b"])
         """
         self._delete_multiple(
-            external_ids=external_id, wrap_ids=True, extra_body_fields={"ignoreUnknownIds": ignore_unknown_ids}
+            identifiers=IdentifierSequence.load(external_ids=external_id),
+            wrap_ids=True,
+            extra_body_fields={"ignoreUnknownIds": ignore_unknown_ids},
         )
