@@ -1,4 +1,4 @@
-from typing import Any, Awaitable, Dict, List, Optional, Union, cast
+from typing import Any, Awaitable, Dict, List, Optional, Union
 
 from cognite.client import utils
 from cognite.client._api.transformations.jobs import TransformationJobsAPI
@@ -14,6 +14,7 @@ from cognite.client.data_classes.transformations import (
     TransformationPreviewResult,
     TransformationUpdate,
 )
+from cognite.client.utils._identifier import IdentifierSequence
 
 
 class TransformationsAPI(APIClient):
@@ -97,7 +98,9 @@ class TransformationsAPI(APIClient):
                 >>> c.transformations.delete(id=[1,2,3], external_id="function3")
         """
         self._delete_multiple(
-            ids=id, external_ids=external_id, wrap_ids=True, extra_body_fields={"ignoreUnknownIds": ignore_unknown_ids}
+            identifiers=IdentifierSequence.load(ids=id, external_ids=external_id),
+            wrap_ids=True,
+            extra_body_fields={"ignoreUnknownIds": ignore_unknown_ids},
         )
 
     def list(
@@ -195,16 +198,11 @@ class TransformationsAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> res = c.transformations.retrieve(external_id="1")
         """
-        utils._auxiliary.assert_exactly_one_of_id_or_external_id(id, external_id)
-        return cast(
-            Optional[Transformation],
-            self._retrieve_multiple(
-                list_cls=TransformationList,
-                resource_cls=Transformation,
-                ids=id,
-                external_ids=external_id,
-                wrap_ids=True,
-            ),
+        identifiers = IdentifierSequence.load(ids=id, external_ids=external_id).as_singleton()
+        return self._retrieve_multiple(
+            list_cls=TransformationList,
+            resource_cls=Transformation,
+            identifiers=identifiers,
         )
 
     def retrieve_multiple(
@@ -228,19 +226,12 @@ class TransformationsAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> res = c.transformations.retrieve_multiple(ids=[1,2,3], external_ids=['transform-1','transform-2'])
         """
-        utils._auxiliary.assert_type(ids, "ids", [list], True)
-        utils._auxiliary.assert_type(external_ids, "external_ids", [list], True)
-
-        return cast(
-            TransformationList,
-            self._retrieve_multiple(
-                list_cls=TransformationList,
-                resource_cls=Transformation,
-                ids=ids,
-                external_ids=external_ids,
-                wrap_ids=True,
-                ignore_unknown_ids=ignore_unknown_ids,
-            ),
+        identifiers = IdentifierSequence.load(ids=ids, external_ids=external_ids)
+        return self._retrieve_multiple(
+            list_cls=TransformationList,
+            resource_cls=Transformation,
+            identifiers=identifiers,
+            ignore_unknown_ids=ignore_unknown_ids,
         )
 
     def update(
@@ -325,7 +316,7 @@ class TransformationsAPI(APIClient):
                 >>>
                 >>> res = c.transformations.run(transformation_id = 1, wait = False)
         """
-        utils._auxiliary.assert_exactly_one_of_id_or_external_id(transformation_id, transformation_external_id)
+        IdentifierSequence.load(transformation_id, transformation_external_id).assert_singleton()
 
         id = {"externalId": transformation_external_id, "id": transformation_id}
 
@@ -391,7 +382,7 @@ class TransformationsAPI(APIClient):
                 >>> if res.status == TransformationJobStatus.RUNNING:
                 >>>     res.cancel()
         """
-        utils._auxiliary.assert_exactly_one_of_id_or_external_id(transformation_id, transformation_external_id)
+        IdentifierSequence.load(transformation_id, transformation_external_id).assert_singleton()
 
         id = {"externalId": transformation_external_id, "id": transformation_id}
 
