@@ -3,19 +3,19 @@ import re
 import time
 import warnings
 from datetime import datetime, timezone
-from typing import Dict, List, Union
+from typing import Dict, List, Optional, Union
 
 _unit_in_ms_without_week = {"s": 1000, "m": 60000, "h": 3600000, "d": 86400000}
 _unit_in_ms = {**_unit_in_ms_without_week, "w": 604800000}
 
 
-def datetime_to_ms(dt):
+def datetime_to_ms(dt: datetime) -> int:
     if dt.tzinfo is None:
         warnings.warn(
             "Interpreting given naive datetime as UTC instead of local time (against Python default behaviour). "
             "This will change in the next major release (4.0.0). Please use (timezone) aware datetimes "
             "or convert it yourself to integer (number of milliseconds since epoch, leap seconds excluded).",
-            DeprecationWarning,
+            FutureWarning,
         )
         dt = dt.replace(tzinfo=timezone.utc)
     return int(1000 * dt.timestamp())
@@ -38,12 +38,12 @@ def ms_to_datetime(ms: Union[int, float]) -> datetime:
         "This function, `ms_to_datetime` returns a naive datetime object in UTC. This is against "
         "the default interpretation of naive datetimes in Python (i.e. local time). This behaviour will "
         "change to returning timezone-aware datetimes in UTC in the next major release (4.0.0).",
-        DeprecationWarning,
+        FutureWarning,
     )
     return datetime.utcfromtimestamp(ms / 1000)
 
 
-def time_string_to_ms(pattern, string, unit_in_ms):
+def time_string_to_ms(pattern: str, string: str, unit_in_ms: Dict[str, int]) -> Optional[int]:
     pattern = pattern.format("|".join(unit_in_ms))
     res = re.fullmatch(pattern, string)
     if res:
@@ -93,7 +93,7 @@ def timestamp_to_ms(timestamp: Union[int, float, str, datetime]) -> int:
         int: Milliseconds since epoch representation of timestamp
     """
     if isinstance(timestamp, numbers.Number):  # float, int, int64 etc
-        ms = int(timestamp)
+        ms = int(timestamp)  # type: ignore[arg-type]
     elif isinstance(timestamp, str):
         ms = int(round(time.time() * 1000)) - time_ago_to_ms(timestamp)
     elif isinstance(timestamp, datetime):
@@ -126,7 +126,7 @@ def _convert_time_attributes_in_dict(item: Dict) -> Dict:
     for k, v in item.items():
         if k in TIME_ATTRIBUTES:
             try:
-                v = ms_to_datetime(v).strftime("%Y-%m-%d %H:%M:%S")
+                v = str(datetime.utcfromtimestamp(v / 1000))
             except (ValueError, OSError):
                 pass
         new_item[k] = v
